###################################################
### chunk number 1: 
###################################################
options(prompt="R> ")


###################################################
### chunk number 2:  eval=FALSE
###################################################
## vignette("laeken-standard")
## vignette("laeken-variance")


###################################################
### chunk number 3: 
###################################################
library("laeken")
data("eusilc")


###################################################
### chunk number 4: 
###################################################
qsr("eqIncome", weights = "rb050", data = eusilc)   


###################################################
### chunk number 5: 
###################################################
gini("eqIncome", weights = "rb050", data = eusilc)


###################################################
### chunk number 6: 
###################################################
x <- seq(1, 6, length.out=1000)
dpareto <- function(x, x0 = 1, theta = 1) theta*x0^theta / x^(theta+1)
y1 <- dpareto(x, theta=1)
y2 <- dpareto(x, theta=2)
y3 <- dpareto(x, theta=3)


###################################################
### chunk number 7: 
###################################################
par(mar = c(4, 4, 0.5, 0.5) + 0.1)
plot(x, y3, type = "l", lty = 3, ylab = "f(x)", xlim = c(0.75, 6), 
    panel.first = {
        abline(h = 0, col = grey(0.75))
        abline(v = 1, col = grey(0.75))
    })
lines(x, y2, lty = 2)
lines(x, y1, lty = 1)
leg <- expression(paste(theta, " = 1"), paste(theta, " = 2"), paste(theta, " = 3"))
legend("topright", legend = leg, lty = 1:3)


###################################################
### chunk number 8: 
###################################################
hID <- eusilc$db030[which.max(eusilc$eqIncome)]
eusilc[eusilc$db030 == hID, "eqIncome"] <- 10000000


###################################################
### chunk number 9: 
###################################################
# equivalized disposable income is equal for each household
# member, therefore only one household member is taken
eusilcH <- eusilc[!duplicated(eusilc$db030), c("eqIncome", "db090")]


###################################################
### chunk number 10: 
###################################################
ts <- paretoScale(eusilcH$eqIncome, w = eusilcH$db090)
ts


###################################################
### chunk number 11: 
###################################################
# with sample weights
paretoQPlot(eusilcH$eqIncome, w = eusilcH$db090)


###################################################
### chunk number 12: 
###################################################
# with sample weights
meanExcessPlot(eusilcH$eqIncome, w = eusilcH$db090)


###################################################
### chunk number 13: 
###################################################
# using number of observations in tail
thetaHill(eusilcH$eqIncome, k = ts$k, w = eusilcH$db090)
# using threshold
thetaHill(eusilcH$eqIncome, x0 = ts$x0, w = eusilcH$db090)


###################################################
### chunk number 14: 
###################################################
# using number of observations in tail
thetaWML(eusilcH$eqIncome, k = ts$k)
# using threshold
thetaWML(eusilcH$eqIncome, x0 = ts$x0)


###################################################
### chunk number 15: 
###################################################
# using number of observations in tail
thetaISE(eusilcH$eqIncome, k = ts$k, w = eusilcH$db090)
# using threshold
thetaISE(eusilcH$eqIncome, x0 = ts$x0, w = eusilcH$db090)


###################################################
### chunk number 16: 
###################################################
# using number of observations in tail
thetaPDC(eusilcH$eqIncome, k = ts$k, w = eusilcH$db090)
# using threshold
thetaPDC(eusilcH$eqIncome, x0 = ts$x0, w = eusilcH$db090)


###################################################
### chunk number 17: 
###################################################
## gini coefficient without Pareto tail modeling
gini("eqIncome", weights = "rb050", data = eusilc)


###################################################
### chunk number 18: 
###################################################
## gini coefficient with Pareto tail modeling
fit <- paretoTail(eusilc$eqIncome, k = ts$k, 
    w = eusilc$db090, groups = eusilc$db030)


###################################################
### chunk number 19: 
###################################################
# calibration of outliers
w <- reweightOut(fit, calibVars(eusilc$db040))
gini(eusilc$eqIncome, w)


###################################################
### chunk number 20: 
###################################################
# replacement of outliers
set.seed(1234)
eqIncome <- replaceOut(fit)
gini(eqIncome, weights = eusilc$rb050)


###################################################
### chunk number 21: 
###################################################
# replacement of whole tail
set.seed(1234)
eqIncome <- replaceTail(fit)
gini(eqIncome, weights = eusilc$rb050)


